@@ -145,7 +145,7 @@ class App:
         return self.cur_req.cookies
 
     def get_cookie(self, key):
-        return self.cur_req.cookies()
+        return dict(self.cur_req.cookies)[key]
 
     def run(self):
         try:
