@@ -10,7 +10,7 @@ class Session:
         if self.lifetime == "session":
             self.app.set_cookie(key, value)
         else:
-            self.app.set_cookie(key, value, expires=self.lifetime)
+            self.app.set_cookie(key, value, lifetime=self.lifetime)
         self._dict[key] = value
     
     def __getitem__(self, key):
